<?php

# Configuration #

# Full path to rtmpdump
$rtmpdump = '/usr/local/bin/rtmpdump';

# Where to save downloaded FLV files
$output_directory = '/home/gb/tou.tv/videos';

# If you want to play videos (on the devices that support Flash), put the URL that points to the above directory here
$web_output_directory = 'videos';

### Don't touch below! ###

define('TOU_TV_BASE_URL', 'http://www.tou.tv');
define('TOU_TV_REPERTOIRE_URL', '/repertoire');
define('TOU_TV_MEDIA_FLAG', 'toutv.mediaData');
define('THEPLATFORM_CONTENT_URL', 'http://release.theplatform.com/content.select?pid=');

$db_path = './toutv.sqlite3';
if (!file_exists($db_path)) {
	// create the db automatically if it does not exist
	system("sqlite3 $db_path < toutv.sql");
}
$dbh = new PDO("sqlite:" . $db_path);

if (isset($argv)) {
	if ($argc > 1 && $argv[1] == 'cron') {
		$already_running = exec('ps aux | grep " index.php cron" | grep -v grep | wc -l');
		if ($already_running > 3) {
			echo "Already encoding (index.php cron). Exiting.\n";
			exit(0);
		}
		set_time_limit(0); // No time limit! Encode forever...

		$sql = "SELECT * FROM subs ORDER BY name";
		$result = $dbh->query($sql);
		while ($serie = $result->fetchObject()) {

			$eps = getSerieEpisodes($serie->url);
			foreach ($eps as $ep) {
				$sql = sprintf("SELECT * FROM downloaded WHERE url = %s",
					$dbh->quote($ep->url)
				);
				$result2 = $dbh->query($sql);
				$row2 = $result2->fetchObject();
				if (!$row2) {
					// New episode
					echo "New episode! $ep->url\nDownloading...\n";
					downloadFLV($ep->url, $serie->name, $ep->saison . " - " . $ep->title, FALSE);
					
					$sql = sprintf("INSERT INTO downloaded (serie_name, url) VALUES (%s, %s)",
						$dbh->quote($serie->name),
						$dbh->quote($ep->url)
					);
					$dbh->query($sql);
				}
			}
		}
	}
	exit(0);
}

header('Content-Type: text/html; charset=utf-8');

if (isset($_GET['subscribe'])) {
	$sql = sprintf("INSERT INTO subs (name, url) VALUES (%s, %s)",
		$dbh->quote($_GET['name']),
		$dbh->quote($_GET['url'])
	);
	$dbh->query($sql);

	$eps = getSerieEpisodes($_GET['url']);
	foreach ($eps as $ep) {
		$sql = sprintf("INSERT INTO downloaded (serie_name, url) VALUES (%s, %s)",
			$dbh->quote($_GET['name']),
			$dbh->quote($ep->url)
		);
		$dbh->query($sql);
	}
}
if (isset($_GET['unsubscribe'])) {
	$sql = sprintf("DELETE FROM subs WHERE url = %s",
		$dbh->quote($_GET['url'])
	);
	$dbh->query($sql);

	$eps = getSerieEpisodes($_GET['url']);
	foreach ($eps as $ep) {
		$sql = sprintf("DELETE FROM downloaded WHERE url = %s",
			$dbh->quote($ep->url)
		);
		$dbh->query($sql);
	}
}
if (isset($_GET['download_all'])) {
	$eps = getSerieEpisodes($_GET['url']);
	foreach ($eps as $ep) {
		$sql = sprintf("DELETE FROM downloaded WHERE url = %s",
			$dbh->quote($ep->url)
		);
		$dbh->query($sql);
	}
}
if (@$_GET['mode'] == 'serie') {
	$sql = sprintf("SELECT * FROM subs WHERE url = %s",
		$dbh->quote($_GET['url'])
	);
	$result = $dbh->query($sql);
	$row = $result->fetchObject();
	$subscribed = FALSE;
	if ($row) {
		$subscribed = TRUE;
	}
}

if (@$_GET['mode'] == 'edit' && isset($_GET['del'])) {
	if (strpos($_GET['del'], '..') === FALSE && strpos($_GET['del'], ".flv") !== FALSE) {
		unlink("$output_directory/" . $_GET['del']);
	}
}

$isTV = FALSE;
if (strpos($_SERVER['HTTP_USER_AGENT'], 'Large Screen') !== FALSE) {
	$isTV = TRUE;
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">

<head>
<meta content="yes" name="apple-mobile-web-app-capable" />
<meta content="text/html; charset=utf-8" http-equiv="Content-Type" />
<meta content="minimum-scale=1.0, width=device-width, maximum-scale=0.6667, user-scalable=no" name="viewport" />
<link href="css/style.css" rel="stylesheet" media="screen" type="text/css" />
<?php if ($isTV) {
	echo '<link href="css/tv.css" rel="stylesheet" media="screen" type="text/css" />';
} ?>
<script type="text/javascript" src="javascript/functions.js"></script>
<script type="text/javascript" src="javascript/jquery-1.4.3.min.js"></script>
<script type="text/javascript" src="javascript/keynav.js"></script>
<?php
if (isset($_GET['download_all'])) {
	?><script type="text/javascript">alert('All past and future episodes of this serie will be downloaded automatically.');</script><?php
}
if (isset($_GET['subscribe'])) {
	?><script type="text/javascript">alert('All future episodes of this serie will be downloaded automatically.');</script><?php
}
?>
<title>tou.tv pour iPad</title>
</head>

<body class="<?php echo (!isset($_GET['mode']) ? 'musiclist' : ($_GET['mode'] == 'serie' ? 'list' : ($_GET['mode'] == 'edit' ? 'list' : ''))) ?>">

<div id="topbar" class="transparent toutv">
	<div id="leftnav">
	<?php
	if (isset($_GET['play_local'])) {
		echo "<a href='index.php?mode=edit'>Retour</a>\n";
	} else {
		if (@$_GET['mode'] == 'serie' || @$_GET['mode'] == 'episode') {
			echo "<a href='index.php'>R&eacute;pertoire</a>\n";
		}
		if (@$_GET['mode'] == 'episode') {
			echo "<a href='index.php?mode=serie&name=".urlencode($_GET['name'])."&url=".urlencode($_GET['serie_url'])."'>".htmlentities($_GET['name'])."</a>\n";
		}
	}
	if (@$_GET['mode'] == 'edit') {
		echo "<a href='index.php'>Retour</a>\n";
	}
	?>
	</div>
	<div id="title">
	<?php
	if (!isset($_GET['mode'])) {
		echo "tou.tv - R&eacute;pertoire";
	} else if ($_GET['mode'] == 'edit') {
		echo "G&eacute;rer les T&eacute;l&eacute;chargements";
	} else if ($_GET['mode'] == 'serie') {
		echo htmlentities($_GET['name']);
	} else if ($_GET['mode'] == 'episode' && !$isTV) {
		echo "<span class='episode_title'>".htmlentities($_GET['title'])."</span>";
	}
	?>
	</div>
	<div id="<?php echo @$_GET['mode'] == 'edit' ? 'rightbutton' : 'rightnav' ?>">
	<?php
	if (@$_GET['mode'] == 'serie') {
		if ($subscribed) {
			echo "<a href='index.php?mode=serie&name=".urlencode($_GET['name'])."&url=".urlencode($_GET['url'])."&unsubscribe=1' class='noeffect' onclick='this.innerHTML=\"Please wait...\"; window.location=this.getAttribute(\"href\"); return false'>Unsubscribe</a>\n";
			echo "<a href='index.php?mode=serie&name=".urlencode($_GET['name'])."&url=".urlencode($_GET['url'])."&download_all=1' title='Télécharger tous les épisodes' class='noeffect' onclick='this.innerHTML=\"Please wait...\"; window.location=this.getAttribute(\"href\"); return false' id='download_all_button'>Download All!</a>\n";
		} else {
			echo "<a href='index.php?mode=serie&name=".urlencode($_GET['name'])."&url=".urlencode($_GET['url'])."&subscribe=1' title='Télécharger les nouveaux épisodes automatiquement' class='noeffect' onclick='this.innerHTML=\"Please wait...\"; window.location=this.getAttribute(\"href\"); return false'>Subscribe</a>\n";
		}
	}
	if (!isset($_GET['mode'])) {
		echo "<a href='index.php?mode=edit' class='noeffect' onclick='this.innerHTML=\"Please wait...\"; window.location=this.getAttribute(\"href\"); return false'>T&eacute;l&eacute;chargements</a>\n";
	} else if ($_GET['mode'] == 'edit') {
		echo "<a href='#' class='noeffect' onclick='go_edit(this); return false'>&nbsp; Effacer... &nbsp;</a>\n";
	}
	?>
	</div>
</div>
<script type="text/javascript">
function done_edit(button_el) {
	button_el.innerHTML = '&nbsp; Effacer... &nbsp;';
	button_el.onclick = function(){ go_edit(button_el); return false; };
	$(button_el).parent().attr('id', 'rightbutton');
	$('#content ul li[class!="title"]').each(function(){
		$(this).removeClass('editing');
		$(this).find('.small_delete').detach();
		$(this).find('a').each(function(){ this.onclick = function() { window.location=this.getAttribute("href"); return false; }; });
	});
	$('.arrow.delete').each(function() {
		$(this).removeClass('delete');
		this.onclick = null;
	});
}

function go_edit(button_el) {
	button_el.innerHTML = '&nbsp; Termin&eacute; &nbsp;';
	button_el.onclick = function(){ done_edit(button_el); return false; };
	$(button_el).parent().attr('id', 'bluerightbutton');
	$('#content ul li[class!="title"]').each(function() {
		$(this).addClass('editing');
		$(this).find('a').prepend('<span class="small_delete" onclick="go_edit2(this)"></span>');
		$(this).find('a').each(function(){ this.onclick = function() { return false; }; });
	});
}

function go_edit2(del_button_el) {
	del_button_el.onclick = function() { cancel_edit2(del_button_el); };
	$(del_button_el).css('background-image', 'url(../images/delete_round_vert.png)');
	$(del_button_el).parent().find('.arrow').each(function() {
		$(this).addClass('delete');
		var url_parts = $(this).parent().attr('href').split('&');
		for (var i=0; i<url_parts.length; i++) {
			var url_part = url_parts[i];
			if (url_part.indexOf('url=') == 0) {
				var file_path = url_part.substr(4, url_part.length);
				break;
			}
		}
		this.onclick = function() {
			$.ajax({ url: 'index.php?mode=edit&del=' + file_path, success: function() {
				$(del_button_el).parent().parent().detach();
			}});
		};
	});
}

function cancel_edit2(del_button_el) {
	del_button_el.onclick = function() { go_edit2(del_button_el); };
	$(del_button_el).css('background-image', 'url(../images/delete_round.png)');
	$(del_button_el).parent().find('.arrow').each(function() {
		$(this).removeClass('delete');
		this.onclick = null;
	});
}

<?php if ($isTV): ?>
	$(document).ready(function() {
	    // Initialize jQuery keyboard navigation for the topbar
	    $('#topbar a').keynav('keynav_focus','keynav');
		<?php if (@$_GET['mode'] != 'episode'): ?>
	    	$('#topbar a:first').addClass('keynav_focus');
			$('#topbar a:first').focus();
		<?php endif; ?>
	});
<?php endif; ?>
</script>
<div id="content">
	<?php
	if (!isset($_GET['mode'])) {
		showRoot();
	} else if ($_GET['mode'] == 'edit') {
		showDownloads();
	} else if ($_GET['mode'] == 'serie') {
		showList($_GET['url'], $_GET['name']);
	} else if ($_GET['mode'] == 'episode') {
		showEpisode($_GET['url'], $_GET['name'], $_GET['title'], @$_GET['thumb'], @$_GET['plot']);
	}
	?>
</div>
<div id="footer">
	<!-- Support iWebKit by sending us traffic; please keep this footer on your page, consider it a thank you for our work :-) -->
	<a class="noeffect" href="http://iwebkit.net">Powered by iWebKit</a></div>
</body>
</html>
<?php
function readUrl($url, $save_to_file=null) {
    $ch = curl_init($url);
    curl_setopt($ch, CURLOPT_ENCODING , "gzip,deflate");
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
    curl_setopt($ch, CURLOPT_HEADER, FALSE);
    curl_setopt($ch, CURLOPT_COOKIEJAR, '/tmp/cookies.tou.tv');
    curl_setopt($ch, CURLOPT_COOKIEFILE, '/tmp/cookies.tou.tv');

    // Fake headers
    $custom_headers = array();
    $host = substr($url, strpos($url, '/')+2);
    $host = substr($host, 0, strpos($host, '/'));

    $custom_headers[] = "Host: $host";
    $custom_headers[] = "User-Agent: Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-US; rv:1.8.1.4) Gecko/20070531 Firefox/2.0.0.4";
    $custom_headers[] = "Accept: image/png,*/*;q=0.5";
    $custom_headers[] = "Accept-Language: en-ca,en-us;q=0.8,en;q=0.6,fr-ca;q=0.4,fr;q=0.2";
    $custom_headers[] = "Accept-Charset: UTF-8,*";
    $custom_headers[] = "Keep-Alive: 300";
    $custom_headers[] = "Connection: keep-alive";
    $custom_headers[] = "If-Modified-Since: Tue, 26 Apr 2005 16:57:51 GMT";
    $custom_headers[] = "If-None-Match: \"21406f-1851-d327a1c0\"";
    $custom_headers[] = "Cache-Control: max-age=0";
    curl_setopt($ch, CURLOPT_HTTPHEADER, $custom_headers);
	if ($save_to_file != null) {
		$fp = fopen($save_to_file, 'w') or die("Can't open $save_to_file for writing.\n");
		curl_setopt($ch, CURLOPT_FILE, $fp);
	} else {
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
	}
	$result = curl_exec($ch);
	if ($result === FALSE) {
		die("Error in readUrl: ".curl_error($ch).": $url\n");
	}
	curl_close($ch);
	if ($save_to_file != null) {
		fclose($fp);
	}
	return mb_convert_encoding(str_replace(array("’", "…", "œ"), array("'", "...", "oe"), $result), "windows-1252", "UTF-8");
}

function showRoot() {
    $url_data = readUrl(TOU_TV_BASE_URL . TOU_TV_REPERTOIRE_URL);
	echo "<ul>\n";
	preg_match_all('|href="(.+?)">\s+<h1 class="titreemission">(.+?)</h1>|', $url_data, $matches);
	foreach ($matches[1] as $i => $url) {
		$name = $matches[2][$i];
        $url = TOU_TV_BASE_URL . $url;
		echo "<li><a href='index.php?mode=serie&name=".urlencode($name)."&url=".urlencode($url)."'><span class='name'>".htmlentities($name)."</span><span class='arrow'></span></a></li>\n";
	}
	echo "</ul>\n";
	?>
	<script type="text/javascript"> 
	  $(document).ready(function() {
	    // Initialize jQuery keyboard navigation for the topbar
	    $('.musiclist #content ul li a').keynav('keynav_focus','keynav');
	    $('.musiclist #content ul li a:first').addClass('keynav_focus');
		$('.musiclist #content ul li a:first').focus();
	  });
	</script>
	<?php
}

function showDownloads() {
	global $output_directory;
	exec('find ' . escapeshellarg($output_directory) . '/ -name "*.flv" | sort', $files);
	$last_serie_name = '';
	foreach ($files as $file) {
		$file = trim(str_replace($output_directory, '', $file), '/');
		list($serie_name, $episode_title) = explode('/', $file);
		if ($serie_name != $last_serie_name) {
			if ($last_serie_name != '') {
				echo "</ul>\n";
			}
			echo "<ul>\n";
			echo "<li class='title'>".htmlentities($serie_name)."</li>\n";
		}
		$last_serie_name = $serie_name;
		echo "<li><a class='noeffect' onclick='window.location=this.getAttribute(\"href\"); return false' href='index.php?mode=episode&play_local=1&name=".urlencode($serie_name)."&title=".urlencode(preg_replace('/\.flv$/', '', $episode_title))."&url=".urlencode($file)."'><span class='name'>".htmlentities(preg_replace('/\.flv$/', '', $episode_title))."</span><span class='arrow'></span></a></li>\n";
	}
	echo "</ul>\n";
	?>
	<script type="text/javascript"> 
	  $(document).ready(function() {
	    // Initialize jQuery keyboard navigation for the topbar
	    $('#content ul li a').keynav('keynav_focus','keynav');
	    $('#content ul li a:first').addClass('keynav_focus');
		$('#content ul li a:first').focus();
	  });
	</script>
	<?php
}

function getSerieEpisodes($url) {
	$episodes = array();
	$url_data = readUrl($url);
	if (strpos($url_data, TOU_TV_MEDIA_FLAG) === FALSE) {
		preg_match_all('|<img id=".+?" src="([^"]+?\.jpe?g)".+?class="saison">(.+?)</p>.+?class="episode".+?href="(.+?)".+?<b>(.+?)(&nbsp;)*?</b>.+?<p>(.+?)</p>|s', $url_data, $matches);
		foreach ($matches[1] as $i => $img) {
			$episodes[] = (object) array(
				'saison' => $matches[2][$i],
				'url' => TOU_TV_BASE_URL . $matches[3][$i],
				'title' => $matches[4][$i],
				'plot' => $matches[6][$i],
				'thumb' => get_thumbnail($img)
			);
		}
	} else {
		preg_match_all('|toutv.mediaData.+?"description":"([^"]*)".+?"seasonNumber":([^,]*),.+?"title":"([^"]*)".+?toutv.imageA=\'([^\']*)\'|', $url_data, $matches);
		$episodes[] = (object) array(
			'saison' => 'Saison ' . $matches[2][0],
			'url' => $url,
			'title' => preg_match('/#([0-9]+)/', $matches[3][0], $re) ? 'Episode '.$re[1] : $matches[3][0],
			'plot' => $matches[1][0],
			'thumb' => get_thumbnail($matches[4][0])
		);
	}
	return $episodes;
}

function showList($url, $name) {
	echo "<ul>\n";
	foreach (getSerieEpisodes($url) as $ep) {
		echo "<li class='withimage'><a href='index.php?mode=episode&name=".urlencode($name)."&serie_url=".urlencode($url)."&title=".urlencode("$ep->saison - $ep->title")."&url=".urlencode($ep->url)."&thumb=".urlencode($ep->thumb)."&plot=".urlencode($ep->plot)."'><img src='$ep->thumb' /><span class='name'>".htmlentities($ep->saison)." - ".htmlentities($ep->title)."</span><span class='comment'>".htmlentities($ep->plot)."</span><span class='arrow'></span></a></li>\n";
	}
	echo "</ul>\n";
	?>
	<script type="text/javascript"> 
	  $(document).ready(function() {
	    // Initialize jQuery keyboard navigation
	    $('li.withimage a').keynav('keynav_focus','keynav');
	  });
	</script>
	<?php
}

function showEpisode($url, $serie_name, $title, $thumb, $plot) {
	global $web_output_directory, $isTV;
	
	if (!isset($_POST['play'])) {
		echo "<ul class='pageitem'>\n";
		if (isset($thumb)) {
			echo "<li class='textbox withimage'><img src='$thumb' style='float: left; padding-right: 15px' /><span>".($isTV ? htmlentities($title) : "")."</span></li>\n";
		} else if ($isTV) {
			echo "<li class='textbox withimage'><span>".htmlentities($title)."</span></li>\n";
		}
		if (isset($plot)) {
			echo "<li class='textbox'>".htmlentities($plot)."</li>\n";
		}
		echo "</ul>\n";
	}

	$download_started = FALSE;
	if (isset($_POST['download']) || isset($_POST['play'])) {
		$download_started = downloadFLV($url, $serie_name, $title);
	}
	if (isset($_POST['download'])) {
		echo "<ul class='pageitem'>\n";
		if ($download_started) {
			echo "<li class='textbox'>The video file named <strong>" . saferize("$serie_name/$title") . "</strong> is now downloading. You can go in ZumoCast to watch it.</li>\n";
		} else {
			echo "<li class='textbox'>The video file named <strong>" . saferize("$serie_name/$title") . "</strong> has already been downloaded. You can go in ZumoCast to watch it.</li>\n";
		}
		echo "</ul>\n";
	} else if (isset($_POST['play']) || isset($_GET['play_local'])) {
		if ($download_started) {
			// Buffer 10s of videos before starting to play it
			sleep(10);
		}
		if (isset($_POST['play'])) {
			$url = str_replace('+', '%20', urlencode(saferize("$web_output_directory/$serie_name/$title.flv")));
		} else {
			$url = str_replace('+', '%20', urlencode(saferize("$web_output_directory/") . $url));
		}
		?>
		<center>
			<object type="application/x-shockwave-flash" data="player_flv_maxi.swf" width="800" height="600" id="flash_player">
			    <param name="movie" value="player_flv_maxi.swf" />
			    <param name="allowFullScreen" value="true" />
				<param name="wmode" value="opaque" />
			    <param name="FlashVars" value="autoplay=1&amp;autoload=1&amp;margin=0&amp;showtime=2&amp;showfullscreen=1&amp;ondoubleclick=fullscreen&amp;shortcut=1&amp;startimage=images/flv_startimage.png&amp;flv=<?php echo $url ?>" />
			</object>
		</center>
		<script type="text/javascript">
			document['flash_player'].tabIndex = 0;
			document['flash_player'].focus();
		</script>
		<?php
	} else {
		// Give a choice: download only or download & play
		?>
		<form action="index.php?mode=episode&amp;name=<?php echo urlencode($_GET['name']) ?>&amp;url=<?php echo urlencode($_GET['url']) ?>&amp;title=<?php echo urlencode($_GET['title']) ?>&amp;thumb=<?php echo urlencode($_GET['thumb']) ?>&amp;plot=<?php echo urlencode($_GET['plot']) ?>&amp;serie_url=<?php echo urlencode($_GET['serie_url']) ?>" method="post">
			<div id="download_play_div">
				<ul class="pageitem">
					<li class="red button">
						<input type="submit" name="download" value="Download" />
					</li>
				</ul>
				<ul class="pageitem" id="download_play" style="display: none">
					<li class="green button">
						<input type="submit" name="play" value="Download &amp; Play" />
					</li>
				</ul>
			</div>
		</form>
		<script type="text/javascript"> 
		  $(document).ready(function() {
		    // Initialize jQuery keyboard navigation
		    $('#download_play_div input').keynav('keynav_focus','keynav');
		    $('#topbar a:last').addClass('keynav_focus');
			$('#topbar a:last').focus();
		  });
		</script>
		<script type="text/javascript">
			var hasFlash = false;
			for (var i=0; i<navigator.mimeTypes.length; i++) {
				if (navigator.mimeTypes[i].type == 'application/x-shockwave-flash') {
					hasFlash = true;
					break;
				}
			}
			if (hasFlash) {
				document.getElementById('download_play').style.display = 'block';
			}
		</script>
		<?php
	}
}

function downloadFLV($url, $serie_name, $title, $background=TRUE) {
	global $output_directory;
	$url_data = readUrl($url);
	if (preg_match("@toutv.releaseUrl='(.+?)'@", $url_data, $match)) {
		$pid = $match[1];
        $url = THEPLATFORM_CONTENT_URL . $pid . '&format=SMIL';
        $url_data = readUrl($url);
		preg_match('@<meta base="rtmp:(.+?)"@', $url_data, $match);
		$rtmp_url = "rtmp:" . $match[1];
		preg_match('@<ref src="mp4:(.+?)"@', $url_data, $match);
		$playpath = "mp4:" . $match[1];

		@mkdir("$output_directory/$serie_name/");
		if (!file_exists(saferize("$output_directory/$serie_name/$title.flv"))) {
			global $rtmpdump;
			exec($rtmpdump . ' --rtmp '.escapeshellarg($rtmp_url).' --playpath '.escapeshellarg($playpath).' -o ' . escapeshellarg(saferize("$output_directory/$serie_name/$title.flv")) . " >/dev/null " . ($background ? "&" : ""));
			return TRUE;
		}
		return FALSE;
	}
}

function saferize($string) {
	$string = strtr($string,
		"\xA1\xAA\xBA\xBF\xC0\xC1\xC2\xC3\xC5\xC7\xC8\xC9\xCA\xCB\xCC\xCD\xCE\xCF\xD0\xD1\xD2\xD3\xD4\xD5\xD8\xD9\xDA\xDB\xDD\xE0\xE1\xE2\xE3\xE5\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF\xF0\xF1\xF2\xF3\xF4\xF5\xF8\xF9\xFA\xFB\xFD\xFF",
		"!ao?AAAAACEEEEIIIIDNOOOOOUUUYaaaaaceeeeiiiidnooooouuuyy");
	$string = strtr($string, array(":"=>"-", "\xC4"=>"Ae", "\xC6"=>"AE", "\xD6"=>"Oe", "\xDC"=>"Ue", "\xDE"=>"TH", "\xDF"=>"ss", "\xE4"=>"ae", "\xE6"=>"ae", "\xF6"=>"oe", "\xFC"=>"ue", "\xFE"=>"th"));
	$string = preg_replace("/Saison ([0-9]+) - Episode ([0-9]+)/", 'S\1E\2', $string);
	$string = str_replace('Saison ', '', $string);
	return $string;
}

function get_thumbnail($thumbnail_url) {
	$filepath = 'thumbs/' . md5($thumbnail_url) . '.jpg';
    if (!file_exists($filepath)) {
		readUrl($thumbnail_url, $filepath);
	}
	return $filepath;
}
?>